@@ -3,25 +3,7 @@
 
 context("Testing the freqlist output")
 
-options(stringsAsFactors=FALSE)
-set.seed(100)
-nsubj <- 90 # need multiple of 3
-mdat <- data.frame(Group = c(rep("High", nsubj/3), rep("Med", nsubj/3), rep("Low", nsubj/3)),
-                   Sex = sample(c("Male", "Female"), nsubj, replace=TRUE),
-                   Age = round(rnorm(nsubj, mean=40, sd=5)),
-                   Phase = ordered(sample(c("I", "II", "III"), nsubj, replace=TRUE), levels=c("I", "II", "III")),
-                   ht_in = round(rnorm(nsubj, mean=65, sd=5)),
-                   time = round(runif(nsubj,0,7)),
-                   status = rbinom(nsubj, 1, prob=0.4),
-                   dt = as.Date(round(rnorm(90, mean=100, sd=2000)), origin="1950/01/01"),
-                   missing = as.character(NA),
-                   trt = factor(sample(c("A", "B"), nsubj, replace=TRUE)),
-                   ethan = factor(c(NA, NA, NA, sample(c("Ethan", "Heinzen"), nsubj - 3, replace=TRUE))),
-                   weights = c(20, 1.5, rep(1, nsubj - 2)))
-mdat$Group.fac <- factor(mdat$Group)
-attr(mdat$ht_in, "label") <- "Height in Inches"
-attr(mdat$trt, "label") <- "Treatment Arm"
-attr(mdat$Age, "label") <- "Age in Years"
+# "mdat" now defined in helper-data.R
 
 TAB <- table(mdat[, c("Group", "Sex", "Phase")])
 TAB.subset <- table(mdat[!(mdat$Group == "Low" & mdat$Sex == "Male"), c("Group", "Sex", "Phase")])
@@ -33,10 +15,8 @@ TAB.na <- table(mdat[, c("trt", "ethan")], useNA = 'a')
 
 test_that("A basic freqlist call", {
   expect_identical(
-    capture.output(summary(freqlist(TAB))),
-    c(""                                                               ,
-      ""                                                               ,
-      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
+    capture.kable(summary(freqlist(TAB))),
+    c("|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
       "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
       "|High  |Female |I     |    4|       4|        4.44|       4.44|",
       "|      |       |II    |    8|      12|        8.89|      13.33|",
@@ -60,10 +40,8 @@ test_that("A basic freqlist call", {
 
 test_that("groupBy option in freqlist call", {
   expect_identical(
-    capture.output(summary(freqlist(TAB, groupBy = "Group"), single = FALSE)),
-    c(""                                                               ,
-      ""                                                               ,
-      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
+    capture.kable(summary(freqlist(TAB, groupBy = "Group"), single = FALSE)),
+    c("|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
       "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
       "|High  |Female |I     |    4|       4|       13.33|      13.33|",
       "|      |       |II    |    8|      12|       26.67|      40.00|",
@@ -97,10 +75,8 @@ test_that("groupBy option in freqlist call", {
 
 test_that("sparse option in freqlist call", {
   expect_identical(
-    capture.output(summary(freqlist(TAB, sparse = TRUE))),
-    c(""                                                               ,
-      ""                                                               ,
-      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
+    capture.kable(summary(freqlist(TAB, sparse = TRUE))),
+    c("|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
       "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
       "|High  |Female |I     |    4|       4|        4.44|       4.44|",
       "|      |       |II    |    8|      12|        8.89|      13.33|",
@@ -126,10 +102,8 @@ test_that("sparse option in freqlist call", {
 
 test_that("NA options in freqlist call", {
   expect_identical(
-    capture.output(summary(freqlist(TAB.na, na.options = "include"))),
-    c(""                                                       ,
-      ""                                                       ,
-      "|trt |ethan   | Freq| cumFreq| freqPercent| cumPercent|",
+    capture.kable(summary(freqlist(TAB.na, na.options = "include"))),
+    c("|trt |ethan   | Freq| cumFreq| freqPercent| cumPercent|",
       "|:---|:-------|----:|-------:|-----------:|----------:|",
       "|A   |Ethan   |   17|      17|       18.89|      18.89|",
       "|    |Heinzen |   16|      33|       17.78|      36.67|",
@@ -139,10 +113,8 @@ test_that("NA options in freqlist call", {
     )
   )
   expect_identical(
-    capture.output(summary(freqlist(TAB.na, na.options = "showexclude"))),
-    c(""                                                       ,
-      ""                                                       ,
-      "|trt |ethan   | Freq| cumFreq| freqPercent| cumPercent|",
+    capture.kable(summary(freqlist(TAB.na, na.options = "showexclude"))),
+    c("|trt |ethan   | Freq| cumFreq| freqPercent| cumPercent|",
       "|:---|:-------|----:|-------:|-----------:|----------:|",
       "|A   |Ethan   |   17|      17|       19.54|      19.54|",
       "|    |Heinzen |   16|      33|       18.39|      37.93|",
@@ -152,10 +124,8 @@ test_that("NA options in freqlist call", {
     )
   )
   expect_identical(
-    capture.output(summary(freqlist(TAB.na, na.options = "remove"))),
-    c(""                                                       ,
-      ""                                                       ,
-      "|trt |ethan   | Freq| cumFreq| freqPercent| cumPercent|",
+    capture.kable(summary(freqlist(TAB.na, na.options = "remove"))),
+    c("|trt |ethan   | Freq| cumFreq| freqPercent| cumPercent|",
       "|:---|:-------|----:|-------:|-----------:|----------:|",
       "|A   |Ethan   |   17|      17|       19.54|      19.54|",
       "|    |Heinzen |   16|      33|       18.39|      37.93|",
@@ -168,8 +138,6 @@ test_that("NA options in freqlist call", {
 test_that("Changing the labels on non-grouped freqlists", {
 
   ref <- c(
-    ""                                                                 ,
-    ""                                                                 ,
     "|Treatment |Ethan Rocks | Freq| cumFreq| freqPercent| cumPercent|",
     "|:---------|:-----------|----:|-------:|-----------:|----------:|",
     "|A         |Ethan       |   17|      17|       18.89|      18.89|",
@@ -180,17 +148,17 @@ test_that("Changing the labels on non-grouped freqlists", {
   )
 
   expect_identical(
-    capture.output(summary(freqlist(TAB.na, na.options = "include"), labelTranslations = c("Treatment", "Ethan Rocks"))),
+    capture.kable(summary(freqlist(TAB.na, na.options = "include"), labelTranslations = c("Treatment", "Ethan Rocks"))),
     ref
   )
 
   expect_identical(
-    capture.output(summary(freqlist(TAB.na, na.options = "include", labelTranslations = list("Treatment", "Ethan Rocks")))),
+    capture.kable(summary(freqlist(TAB.na, na.options = "include", labelTranslations = list("Treatment", "Ethan Rocks")))),
     ref
   )
 
   expect_identical(
-    capture.output(summary(freqlist(TAB.na, na.options = "include", labelTranslations = c("Treatment", "Ethan Rocks")))),
+    capture.kable(summary(freqlist(TAB.na, na.options = "include", labelTranslations = c("Treatment", "Ethan Rocks")))),
     ref
   )
 
@@ -200,15 +168,13 @@ test_that("Changing the labels on non-grouped freqlists", {
   tmp <- freqlist(TAB.na, na.options = "include")
   labels(tmp) <- c("Treatment", "Ethan Rocks")
   expect_identical(
-    capture.output(summary(tmp)),
+    capture.kable(summary(tmp)),
     ref
   )
   labels(tmp) <- NULL
   expect_identical(
-    capture.output(summary(tmp)),
-    c(""                                                       ,
-      ""                                                       ,
-      "|trt |ethan   | Freq| cumFreq| freqPercent| cumPercent|",
+    capture.kable(summary(tmp)),
+    c("|trt |ethan   | Freq| cumFreq| freqPercent| cumPercent|",
       "|:---|:-------|----:|-------:|-----------:|----------:|",
       "|A   |Ethan   |   17|      17|       18.89|      18.89|",
       "|    |Heinzen |   16|      33|       17.78|      36.67|",
@@ -220,7 +186,7 @@ test_that("Changing the labels on non-grouped freqlists", {
 
   labels(tmp) <- c(ethan = "Ethan Rocks", trt = "Treatment", dummy = "Dummy")
   expect_identical(
-    capture.output(summary(tmp)),
+    capture.kable(summary(tmp)),
     ref
   )
 })
@@ -228,10 +194,8 @@ test_that("Changing the labels on non-grouped freqlists", {
 
 test_that("Changing the labels on grouped freqlists", {
   expect_identical(
-    capture.output(summary(freqlist(TAB.na, options = "include", groupBy = "ethan", labelTranslations = c("Treatment", "Ethan")))),
-    c(""                                                             ,
-      ""                                                             ,
-      "|Ethan |Treatment | Freq| cumFreq| freqPercent| cumPercent|"  ,
+    capture.kable(summary(freqlist(TAB.na, options = "include", groupBy = "ethan", labelTranslations = c("Treatment", "Ethan")))),
+    c("|Ethan |Treatment | Freq| cumFreq| freqPercent| cumPercent|"  ,
       "|:-----|:---------|----:|-------:|-----------:|----------:|"  ,
       "|Ethan |A         |   17|      17|       40.48|      40.48|"  ,
       "|      |B         |   25|      42|       59.52|     100.00|"  ,
@@ -253,10 +217,8 @@ test_that("Changing the labels on grouped freqlists", {
 
 test_that("dupLabels works", {
   expect_identical(
-    capture.output(summary(freqlist(TAB), dupLabels = TRUE)),
-    c(""                                                               ,
-      ""                                                               ,
-      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
+    capture.kable(summary(freqlist(TAB), dupLabels = TRUE)),
+    c("|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
       "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
       "|High  |Female |I     |    4|       4|        4.44|       4.44|",
       "|High  |Female |II    |    8|      12|        8.89|      13.33|",
@@ -277,10 +239,8 @@ test_that("dupLabels works", {
     )
   )
   expect_identical(
-    capture.output(summary(freqlist(TAB, groupBy = "Group"), single = FALSE, dupLabels = TRUE)),
-    c(""                                                               ,
-      ""                                                               ,
-      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
+    capture.kable(summary(freqlist(TAB, groupBy = "Group"), single = FALSE, dupLabels = TRUE)),
+    c("|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
       "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
       "|High  |Female |I     |    4|       4|       13.33|      13.33|",
       "|High  |Female |II    |    8|      12|       26.67|      40.00|",
@@ -313,9 +273,8 @@ test_that("dupLabels works", {
 
 test_that("Adding a title", {
   expect_identical(
-    capture.output(summary(freqlist(TAB.na, options = "include", labelTranslations = c("Treatment", "Ethan")), dupLabels = TRUE, title = "Ethan Rocks")),
-    c(""                                                             ,
-      "Table: Ethan Rocks"                                           ,
+    capture.kable(summary(freqlist(TAB.na, options = "include", labelTranslations = c("Treatment", "Ethan")), dupLabels = TRUE, title = "Ethan Rocks")),
+    c("Table: Ethan Rocks"                                           ,
       ""                                                             ,
       "|Treatment |Ethan   | Freq| cumFreq| freqPercent| cumPercent|",
       "|:---------|:-------|----:|-------:|-----------:|----------:|",
@@ -328,10 +287,9 @@ test_that("Adding a title", {
   )
 
   expect_identical(
-    capture.output(summary(freqlist(TAB.na, options = "include", groupBy = "ethan",
+    capture.kable(summary(freqlist(TAB.na, options = "include", groupBy = "ethan",
                                     labelTranslations = c("Treatment", "Ethan")), dupLabels = TRUE, title = "Ethan Rocks")),
-    c(""                                                             ,
-      "Table: Ethan Rocks"                                           ,
+    c("Table: Ethan Rocks"                                           ,
       ""                                                             ,
       "|Ethan |Treatment | Freq| cumFreq| freqPercent| cumPercent|"  ,
       "|:-----|:---------|----:|-------:|-----------:|----------:|"  ,
@@ -355,8 +313,8 @@ test_that("Adding a title", {
 
 test_that("Formula method works", {
   expect_identical(
-    capture.output(summary(freqlist(TAB.na, options = "include"), labelTranslations = c("Trt", "Ethan"))),
-    capture.output(summary(freqlist(~ trt + addNA(ethan), data = mdat), labelTranslations = c("Trt", "Ethan")))
+    capture.kable(summary(freqlist(TAB.na, options = "include"), labelTranslations = c("Trt", "Ethan"))),
+    capture.kable(summary(freqlist(~ trt + addNA(ethan), data = mdat), labelTranslations = c("Trt", "Ethan")))
   )
 })
 
@@ -367,10 +325,8 @@ test_that("Formula method works", {
 
 test_that("11/18/16: Emily Lundt's subsetted table and duplicate label problem", {
   expect_identical(
-    capture.output(summary(freqlist(TAB.subset))),
-    c(""                                                               ,
-      ""                                                               ,
-      "|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
+    capture.kable(summary(freqlist(TAB.subset))),
+    c("|Group |Sex    |Phase | Freq| cumFreq| freqPercent| cumPercent|",
       "|:-----|:------|:-----|----:|-------:|-----------:|----------:|",
       "|High  |Female |I     |    4|       4|        5.19|       5.19|",
       "|      |       |II    |    8|      12|       10.39|      15.58|",
